==> icecat-38.3.0-gnu1.tar.bz2: icecat-38.3.0/testing/mozbase/mozdevice/tests/droidsut_launch.py <==
from sut import MockAgent
import mozdevice
import mozlog
import unittest

class LaunchTest(unittest.TestCase):

    def test_nouserserial(self):
        a = MockAgent(self, commands = [("ps",
                                         "10029	549	com.android.launcher\n"
                                         "10066	1198	com.twitter.android"),
                                        ("info sutuserinfo", ""),
                                        ("exec am start -W -n "
                                         "org.mozilla.icecatmobile/.App -a "
                                         "android.intent.action.VIEW",
                                         "OK\nreturn code [0]")])
        d = mozdevice.DroidSUT("127.0.0.1", port=a.port, logLevel=mozlog.DEBUG)
        d.launchIceCatMobile("org.mozilla.icecatmobile")
        a.wait()

    def test_userserial(self):
        a = MockAgent(self, commands = [("ps",
                                         "10029	549	com.android.launcher\n"
                                         "10066	1198	com.twitter.android"),
                                        ("info sutuserinfo", "User Serial:0"),
                                        ("exec am start --user 0 -W -n "
                                         "org.mozilla.icecatmobile/.App -a "
                                         "android.intent.action.VIEW",
                                         "OK\nreturn code [0]")])
        d = mozdevice.DroidSUT("127.0.0.1", port=a.port, logLevel=mozlog.DEBUG)
        d.launchIceCatMobile("org.mozilla.icecatmobile")
        a.wait()

if __name__ == '__main__':
    unittest.main()

==> icecat-45.7.0-gnu1.tar.bz2: icecat-45.7.0/testing/mozbase/mozdevice/tests/droidsut_launch.py <==
from sut import MockAgent
import mozdevice
import logging
import unittest

class LaunchTest(unittest.TestCase):

    def test_nouserserial(self):
        a = MockAgent(self, commands = [("ps",
                                         "10029	549	com.android.launcher\n"
                                         "10066	1198	com.twitter.android"),
                                        ("info sutuserinfo", ""),
                                        ("exec am start -W -n "
                                         "org.mozilla.icecatmobile/.App -a "
                                         "android.intent.action.VIEW",
                                         "OK\nreturn code [0]")])
        d = mozdevice.DroidSUT("127.0.0.1", port=a.port, logLevel=logging.DEBUG)
        d.launchIceCatMobile("org.mozilla.icecatmobile")
        a.wait()

    def test_userserial(self):
        a = MockAgent(self, commands = [("ps",
                                         "10029	549	com.android.launcher\n"
                                         "10066	1198	com.twitter.android"),
                                        ("info sutuserinfo", "User Serial:0"),
                                        ("exec am start --user 0 -W -n "
                                         "org.mozilla.icecatmobile/.App -a "
                                         "android.intent.action.VIEW",
                                         "OK\nreturn code [0]")])
        d = mozdevice.DroidSUT("127.0.0.1", port=a.port, logLevel=logging.DEBUG)
        d.launchIceCatMobile("org.mozilla.icecatmobile")
        a.wait()

if __name__ == '__main__':
    unittest.main()
